unit DebugFrm;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, Buttons, Utils, IniFiles, ExtCtrls;

type
  TDbgForm = class(TForm)
    Label1: TLabel;
    Label2: TLabel;
    ContinueBtn: TBitBtn;
    Cancel: TBitBtn;
    HelpBtn: TBitBtn;
    Msg: TCheckBox;
    Label3: TLabel;
    Bevel1: TBevel;
    procedure ContinueBtnClick(Sender: TObject);
    procedure FormActivate(Sender: TObject);
    procedure HelpBtnClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
  private
  //IniFileName: String;
    { Dclarations prives }
  public
  FileName : string;
    { Dclarations publiques }
  end;

var
  DbgForm: TDbgForm;

implementation

uses ShellApi, MDIEdit, Main, Version, OutputFrm, InfoFrm;

{$R *.DFM}


Function LogDebugInfo (s: String) : Boolean;
begin
   Result := False;
   If Trim (s) = '' then exit;
   s := UpperCase (s);

   Result :=
   ((Pos ('RECEIVED', s) > 0) and (Pos ('SIGNAL', s) > 0) and (Pos ('SIG', s) > 0) )
   or
   ((Pos ('EXCEPTION', s) > 0) )
   or
   ((Pos ('()', s) > 0) )
   or
   ((Pos (':/', s) > 0) )
   or
   ((Pos ('$00', s) > 0) )
   or
   ((Pos ('0x', s) > 0) )
   or
   ((Pos ('PROGRAM EXITED WITH CODE', s) > 0) )
   or
   ((Pos ('(ERROR #', s) > 0) and (Pos ('AT ', s) > 0))
end;


procedure TDbgForm.ContinueBtnClick(Sender: TObject);
var
t       : TStringList;
s1, s2, s3,
s, Cmd  : String;
h       : THandle;
i       : integer;
begin
  Application.ProcessMessages;
  If Msg.Checked then
  MainForm.IniFile.WriteBool ('Debugger', 'NoMsg', Msg.Checked);

 If (ThisCompiler = GPC) and (NOT MainForm.Standalonedebugger)
 then begin
    InfoForm.Caption := 'Please wait while debugging ...';
    // create a gdb command file
    s := ChangeFileExt (ExtractFileName (FileName), '.dbg');
    s := AddBackSlash (GetTempDir) + s;
    Cmd := Debugger_Command + ' -fullname -readnow -quiet -batch -x ' + s;

    t := TStringList.Create;
    t.Add ('file "' + BackToFrontSlash (FileName) + '"'); // tell gdb of program to debug
    t.Add ('run');                                        // tell gdb to run
    t.Add ('q');                                          // tell gdb to quit
    t.SaveToFile (s);
    t.Free;

    s2 := s; // save current value
    Application.ProcessMessages;
    s := RunDebugCommand (Cmd);
    Application.ProcessMessages;
    InfoForm.Caption := 'Debugging completed';
    If (s <> '')
    then begin
     If s = '-1001' then Exit; // couldn't run gdb
//showmessage (s);

     If Pos ('PROGRAM EXITED NORMALLY', UpperCase (s)) > 0
     then begin
        InfoForm.OkBtn.Click;
        With Mainform
        do begin
           CompileFileOutput.Add (s);
           OutPutForm.Output.Lines.Add (s);
           s := 'Debugged program "' + Filename + '" ran and terminated with no runtime error.' ;
           AddItem ('', '', s);
           CompileFileOutput.Add (s);
           OutPutForm.Output.Lines.Add (s);
        end;
        Exit;
     end;

     t := TStringList.Create;
     t.Text := s;

//     ShowMessage (s);
     With Mainform
     do begin
        CompilerOutput.Items.Clear;
        CompileFileOutput.Clear;
        OutPutForm.Output.Lines.Clear;
        InfoForm.ShowResultsBtn.Enabled := True;
        InfoForm.Label2.Caption := 'Runtime errors: ';
        InfoForm.TotalErrors.Caption := '1';
        Application.ProcessMessages;
        InfoForm.OkBtn.Click;
        Application.ProcessMessages;
        for i := 0 to pred (t.Count) do
          if LogDebugInfo (t [i]) // discard unnecessary messages
          then begin
             AddItem ('', '', t[i]);
             CompileFileOutput.Add (t [i]);
             OutPutForm.Output.Lines.Add (t [i]);
          end;
        t.Free;
        Application.ProcessMessages;

//     ShowMessage (s);
        // see whether a Pascal runtime error code was given
        i := Pos ('(ERROR #', UpperCase (CompileFileOutput.Text));
        If i > 0
        then begin
            //c:/out/aka.exe: cannot open file `fred.foo' for reading (No such file or directory) (error #442 at 4014d9)
            //Program exited with code 052.
            s := CompileFileOutput.Text;
            // parse debug output and try to find the address of the error
            Delete (s, 1, i);
            i := Pos ('AT ', UpperCase (s));
            Delete (s, 1, i + 1);
            i := Pos (')', s);
            Delete (s, i, Length (s));
            s1 := Trim (s);
            t := TStringList.Create;
            t.Add ('file "' + BackToFrontSlash (FileName) + '"');
            t.Add ('info line *0x' + s1);   // can also use "addr2line -e foo.exe 0x303033"
            t.Add ('q');
            t.SaveToFile (s2);
            t.Free;
            s := RunDebugCommand (Cmd);
            s := Trim (s);
            // did we get the error line?
            If (Pos ('LINE ', UpperCase (s)) = 1) //Line 37 of "e:/temp/aka.pas"
            then begin
               Delete (s, 1, 5);
               s3 := Trim (Copy (s, 1, Pos (' ', s)));
               Delete (s, 1, Pos ('"', s));
               Delete (s, Pos ('"', s), Length (s));
               s3 := 'Runtime error located in ' + s + ':' + s3 + ': (memory offset=$' + s1 +')';
               AddItem ('', '', s3);
               CompileFileOutput.Add (s3);
               OutPutForm.Output.Lines.Add (s3);
            end; // if Pos
        end; // i > 0
        ErrorFromDebug (-1);
     end; // with MainForm
   end; // s <> ''
   DeleteFile (s2); // remove gdb command file
   Exit;
  end //ThisCompiler = GPC
  else begin
    h := ShellExecute (Application.MainForm.Handle,
       nil,
       pChar (Debugger_Command),
       pchar (FileName), Nil,
       sw_Show);

    If h < 33
    then begin
       MessageDlg ('I cannot execute the GNU debugger (' + Debugger_Command + '). ' +
       ' Please download gdb (from http://www.mingw.org/download.shtml) and install it.',
       MtError, [MbOK], 0);
       Exit;
    end;
  end; // ThisCompiler <> GPC
end;

procedure TDbgForm.FormActivate(Sender: TObject);
//var IniFile : TIniFile;
begin
  //IniFileName := ExtractFilePath(Application.Exename)+ ChangeFileExt(ExtractFileName(Application.Exename), '.ini');
  //IniFile := TIniFile.Create(IniFilename);
  Msg.Checked := MainForm.IniFile.ReadBool ('Debugger', 'NoMsg', Msg.Checked);
end;

procedure TDbgForm.HelpBtnClick(Sender: TObject);
begin                        
  {$IFDEF CD_VERSION}
  ExecuteFile('index.html', '', ExtractFilePath(Application.Exename)+'Share\gdbtcl\help\', SW_SHOW);
  {$ELSE}
  ExecuteFile(Gdb_hlp, '', ExtractFilePath(Application.Exename)+'Help\', SW_SHOW);
  {$ENDIF}
end;

procedure TDbgForm.FormCreate(Sender: TObject);
begin
  //IniFileName := DevPasIniFile;
end;

end.
